@@ -27,7 +27,7 @@ def dingding(access_token, content):
     return "fail: %s" % data.text
 
 
-def falcon(metric, value, ctype, tag, step=60):
+def falcon(metric, value, tag, ctype='GAUGE', step=60):
     '''
     推送方式：falcon
     '''
